==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/MarketFacilitationIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { MarketFacilitationIndexIndicatorDescription } from "./MarketFacilitationIndexIndicatorDescription";
/**
 * @hidden
 */
export let MarketFacilitationIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MarketFacilitationIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MarketFacilitationIndexIndicatorDescriptionMetadata.a == null) {
                MarketFacilitationIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MarketFacilitationIndexIndicatorDescriptionMetadata.c(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
            }
            if (a.j(MarketFacilitationIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MarketFacilitationIndexIndicatorDescriptionMetadata.b(a);
            a.aa("MarketFacilitationIndexIndicator", () => new MarketFacilitationIndexIndicatorDescription());
            a.z("MarketFacilitationIndexIndicator", MarketFacilitationIndexIndicatorDescriptionMetadata.a);
        }
    }
    MarketFacilitationIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(MarketFacilitationIndexIndicatorDescriptionMetadata, 'MarketFacilitationIndexIndicatorDescriptionMetadata');
    MarketFacilitationIndexIndicatorDescriptionMetadata.a = null;
    return MarketFacilitationIndexIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/MarketFacilitationIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ItemwiseStrategyBasedIndicatorDescriptionMetadata } from "./ItemwiseStrategyBasedIndicatorDescriptionMetadata";
import { MarketFacilitationIndexIndicatorDescription } from "./MarketFacilitationIndexIndicatorDescription";
/**
 * @hidden
 */
export let MarketFacilitationIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MarketFacilitationIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MarketFacilitationIndexIndicatorDescriptionMetadata.a == null) {
                MarketFacilitationIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MarketFacilitationIndexIndicatorDescriptionMetadata.c(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(MarketFacilitationIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(MarketFacilitationIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            ItemwiseStrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MarketFacilitationIndexIndicatorDescriptionMetadata.b(a);
            a.ac("MarketFacilitationIndexIndicator", () => new MarketFacilitationIndexIndicatorDescription());
            a.ab("MarketFacilitationIndexIndicator", MarketFacilitationIndexIndicatorDescriptionMetadata.a);
        }
    }
    MarketFacilitationIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(MarketFacilitationIndexIndicatorDescriptionMetadata, 'MarketFacilitationIndexIndicatorDescriptionMetadata');
    MarketFacilitationIndexIndicatorDescriptionMetadata.a = null;
    return MarketFacilitationIndexIndicatorDescriptionMetadata;
})();
